@@ -1,14 +1,23 @@
 import Node from '../Node.js';
+import CompileError from '../../utils/CompileError.js';
 import removeTrailingComma from '../../utils/removeTrailingComma.js';
 
 export default class ArrowFunctionExpression extends Node {
 	initialise(transforms) {
+		if (this.async && transforms.asyncAwait) {
+			CompileError.missingTransform("async arrow functions", "asyncAwait", this);
+		}
 		this.body.createScope();
 		super.initialise(transforms);
 	}
 
 	transpile(code, transforms) {
-		const naked = this.params.length === 1 && this.start === this.params[0].start;
+		let openParensPos = this.start;
+		for (let end = (this.body || this.params[0]).start - 1; code.original[openParensPos] !== '(' && openParensPos < end;) {
+			++openParensPos;
+		}
+		if (code.original[openParensPos] !== '(') openParensPos = -1;
+		const naked = openParensPos === -1;
 
 		if (transforms.arrow || this.needsArguments(transforms)) {
 			// remove arrow
@@ -26,12 +35,22 @@ export default class ArrowFunctionExpression extends Node {
 				code.appendLeft(this.params[0].end, ')');
 			}
 
-			// add function
-			if (this.parent && this.parent.type === 'ExpressionStatement') {
-				// standalone expression statement
-				code.prependRight(this.start, '!function');
+			// standalone expression statement
+			const standalone = this.parent && this.parent.type === 'ExpressionStatement';
+			let start, text = standalone ? '!' : '';
+			if (this.async) text += 'async ';
+			text += 'function';
+			if (!standalone) text += ' ';
+			if (naked) {
+				start = this.params[0].start;
 			} else {
-				code.prependRight(this.start, 'function ');
+				start = openParensPos;
+			}
+			// add function
+			if (start > this.start) {
+				code.overwrite(this.start, start, text);
+			} else {
+				code.prependRight(this.start, text);
 			}
 		} else {
 			super.transpile(code, transforms);
