@@ -1,11 +1,24 @@
 import LoopStatement from './shared/LoopStatement.js';
 import extractNames from '../extractNames.js';
+import Scope from '../Scope.js';
 
 export default class ForStatement extends LoopStatement {
+	initialise(transforms) {
+		this.createdDeclarations = [];
+
+		this.scope = new Scope({
+			block: true,
+			parent: this.parent.findScope(false),
+			declare: id => this.createdDeclarations.push(id)
+		});
+
+		super.initialise(transforms);
+	}
+
 	findScope(functionScope) {
-		return functionScope || !this.createdScope
+		return functionScope
 			? this.parent.findScope(functionScope)
-			: this.body.scope;
+			: this.scope;
 	}
 
 	transpile(code, transforms) {
@@ -13,15 +26,9 @@ export default class ForStatement extends LoopStatement {
 
 		if (this.shouldRewriteAsFunction) {
 			// which variables are declared in the init statement?
-			const names =
-				this.init.type === 'VariableDeclaration'
-					? [].concat.apply(
-							[],
-							this.init.declarations.map(declarator =>
-								extractNames(declarator.id)
-							)
-						)
-					: [];
+			const names = this.init && this.init.type === 'VariableDeclaration'
+				? this.init.declarations.map(declarator => extractNames(declarator.id))
+				: [];
 
 			const aliases = this.aliases;
 
