@@ -16,6 +16,10 @@ export default class Identifier extends Node {
 	}
 
 	initialise(transforms) {
+		if (this.isLabel()) {
+			return;
+		}
+
 		if (isReference(this, this.parent)) {
 			if (
 				transforms.arrow &&
@@ -43,6 +47,15 @@ export default class Identifier extends Node {
 		}
 	}
 
+	isLabel() {
+		switch (this.parent.type) {
+			case 'BreakStatement': return true;
+			case 'ContinueStatement': return true;
+			case 'LabeledStatement': return true;
+			default: return false;
+		}
+	}
+
 	transpile(code) {
 		if (this.alias) {
 			code.overwrite(this.start, this.end, this.alias, {
