@@ -1,7 +1,15 @@
+import CompileError from '../../utils/CompileError.js';
 import Node from '../Node.js';
 import reserved from '../../utils/reserved.js';
 
 export default class Property extends Node {
+	initialise(transforms) {
+		if ((this.kind === 'get' || this.kind === 'set') && transforms.getterSetter) {
+			CompileError.missingTransform("getters and setters", "getterSetter", this);
+		}
+		super.initialise(transforms);
+	}
+
 	transpile(code, transforms) {
 		super.transpile(code, transforms);
 
@@ -36,10 +44,10 @@ export default class Property extends Node {
 					name = ' ' + name;
 				}
 
-				if (this.value.generator) code.remove(this.start, this.key.start);
+				if (this.start < this.key.start) code.remove(this.start, this.key.start);
 				code.appendLeft(
 					this.key.end,
-					`: function${this.value.generator ? '*' : ''}${name}`
+					`: ${this.value.async ? 'async ' : ''}function${this.value.generator ? '*' : ''}${name}`
 				);
 			}
 		}
